﻿using Syncfusion.UI.Xaml.Grid;
using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.Specialized;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using WpfTestingSample.Model;
using Syncfusion.Data;
using Syncfusion.Data.Extensions;
using Syncfusion.UI.Xaml.Grid.Cells;

namespace WpfTestingSample
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    /// 
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            //default CaptionSummaryCellRenderer is removed.            
            this.datagrid.CellRenderers.Remove("CaptionSummary");

            //Customized CaptionSummaryCellRenderer is added.
            this.datagrid.CellRenderers.Add("CaptionSummary", new CustomCaptionSummaryCellRenderer());

            
        }

       
    }

    public class CustomCaptionSummaryCellRenderer : GridCaptionSummaryCellRenderer
    {
        public override void OnInitializeEditElement(DataColumnBase dataColumn, GridCaptionSummaryCell uiElement, object dataContext)
        {
            if (dataContext is Group)
            {
                var groupRecord = dataContext as Group;
                if (this.DataGrid.CaptionSummaryRow == null)
                {
                    // get the column which is grouped
                    var groupedColumn = this.GetGroupedColumn(groupRecord);
                    //set the captionsummarycell text as customized.
                    uiElement.Content = GetCustomizedCaptionText(groupedColumn.MappingName, groupRecord.Key,
                        groupRecord.ItemsCount);
                }
                else if (this.DataGrid.CaptionSummaryRow.ShowSummaryInRow)
                {
                    uiElement.Content = SummaryCreator.GetSummaryDisplayTextForRow(groupRecord.SummaryDetails,
                        this.DataGrid.View);
                }
                else
                    uiElement.Content = SummaryCreator.GetSummaryDisplayText(groupRecord.SummaryDetails,
                        dataColumn.GridColumn.MappingName, this.DataGrid.View);
            }
        }

        public override void OnUpdateEditBinding(DataColumnBase dataColumn, GridCaptionSummaryCell element, object dataContext)
        {
            if (element.DataContext is Group && this.DataGrid.View.GroupDescriptions.Count > 0)
            {
                var groupRecord = element.DataContext as Group;
                //get the column which is grouped.
                var groupedColumn = this.GetGroupedColumn(groupRecord);
                if (this.DataGrid.CaptionSummaryRow == null)
                {
                    if (this.DataGrid.View.GroupDescriptions.Count < groupRecord.Level)
                        return;
                    //set the captionsummary text as customized.
                    

                  element.Content = GetCustomizedCaptionText(groupedColumn.MappingName, groupRecord.Key,
                        groupRecord.ItemsCount);
                }
                else if (this.DataGrid.CaptionSummaryRow.ShowSummaryInRow)
                {
                    element.Content = SummaryCreator.GetSummaryDisplayTextForRow(groupRecord.SummaryDetails,
                        this.DataGrid.View, groupedColumn.HeaderText);
                }
                else
                    element.Content = SummaryCreator.GetSummaryDisplayText(groupRecord.SummaryDetails,
                        dataColumn.GridColumn.MappingName, this.DataGrid.View);
            }
        }

        // Method to get the Grouped Column.
        private GridColumn GetGroupedColumn(Group group)
        {
            var groupDesc = this.DataGrid.View.GroupDescriptions[group.Level - 1] as PropertyGroupDescription;
            foreach (var column in this.DataGrid.Columns)
            {
                if (column.MappingName == groupDesc.PropertyName)
                {
                    return column;
                }
            }
            return null;
        }

        // Method to Customize the CaptionSummaryCell Text.
        private string GetCustomizedCaptionText(string columnName, object groupKey, int itemsCount)
        {
            
            string entryText = string.Empty;

          switch(groupKey.ToString())
          {
              case "NR" :
                  entryText = "NAURU";
                  break;

              case "NP":
                  entryText = "NEPAL";
                  break;
              case "NL":
                  entryText = "NETHERLANDS";
                  break;
              case "NZ":
                  entryText = "NEW ZEALAND";
                  break;
              case "NI":
                  entryText = "NICARAGUA";
                  break;
              case "NE":
                  entryText = "NIGER";
                  break;
              case "NG":
                  entryText = "NIGERIA";
                  break;
              case "NU":
                  entryText = "NIUE";
                  break;

          }
          if (entryText == string.Empty)
              entryText = groupKey.ToString();
          return string.Format("{0}: {1} - {2}", columnName, entryText, itemsCount);
        }
    }
    public class DisplayMemberConverter : IValueConverter
    {
        public string DisplayMemberPath { get; set; }
        public string SelectedValuePath { get; set; }
        public object  DataContext { get; set; }

        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            var selectedValue = value;
            IEnumerable list = null;
            var displayMemberPath = DisplayMemberPath;
            var valueMemberPath = SelectedValuePath;

            list = (DataContext as ViewModel).Companies;
            
            if (selectedValue == null)
                return null;

            PropertyDescriptorCollection pdc = null;

            if (string.IsNullOrEmpty(valueMemberPath))
            {
                if (!string.IsNullOrEmpty(displayMemberPath))
                {
                    var type = selectedValue.GetType();

                    pdc = TypeDescriptor.GetProperties(type);

                    return pdc.GetValue(selectedValue, displayMemberPath);
                }
                return selectedValue;
            }
            else
            {
                if (list == null)
                    return null;

                var enumerator = list.GetEnumerator();
                while (enumerator.MoveNext())
                {
                    var type = enumerator.Current.GetType();
                    pdc = pdc ?? TypeDescriptor.GetProperties(type);

                    if (selectedValue.Equals(pdc.GetValue(enumerator.Current, valueMemberPath)))
                    {
                        if (!string.IsNullOrEmpty(displayMemberPath))
                            return pdc.GetValue(enumerator.Current, displayMemberPath);
                        return enumerator.Current;
                    }
                }
            }
            return null;
        }

        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            return value;
        }

    }

  
}
